==> vtk-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkRandomAttributeGenerator.java <==
// java wrapper for vtkRandomAttributeGenerator object
//

package vtk;
import vtk.*;

public class vtkRandomAttributeGenerator extends vtkPassInputTypeAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetDataType_2(int id0);
  public void SetDataType(int id0)
    { SetDataType_2(id0); }

  private native void SetDataTypeToBit_3();
  public void SetDataTypeToBit()
    { SetDataTypeToBit_3(); }

  private native void SetDataTypeToChar_4();
  public void SetDataTypeToChar()
    { SetDataTypeToChar_4(); }

  private native void SetDataTypeToUnsignedChar_5();
  public void SetDataTypeToUnsignedChar()
    { SetDataTypeToUnsignedChar_5(); }

  private native void SetDataTypeToShort_6();
  public void SetDataTypeToShort()
    { SetDataTypeToShort_6(); }

  private native void SetDataTypeToUnsignedShort_7();
  public void SetDataTypeToUnsignedShort()
    { SetDataTypeToUnsignedShort_7(); }

  private native void SetDataTypeToInt_8();
  public void SetDataTypeToInt()
    { SetDataTypeToInt_8(); }

  private native void SetDataTypeToUnsignedInt_9();
  public void SetDataTypeToUnsignedInt()
    { SetDataTypeToUnsignedInt_9(); }

  private native void SetDataTypeToLong_10();
  public void SetDataTypeToLong()
    { SetDataTypeToLong_10(); }

  private native void SetDataTypeToUnsignedLong_11();
  public void SetDataTypeToUnsignedLong()
    { SetDataTypeToUnsignedLong_11(); }

  private native void SetDataTypeToFloat_12();
  public void SetDataTypeToFloat()
    { SetDataTypeToFloat_12(); }

  private native void SetDataTypeToDouble_13();
  public void SetDataTypeToDouble()
    { SetDataTypeToDouble_13(); }

  private native int GetDataType_14();
  public int GetDataType()
    { return GetDataType_14(); }

  private native void SetNumberOfComponents_15(int id0);
  public void SetNumberOfComponents(int id0)
    { SetNumberOfComponents_15(id0); }

  private native int GetNumberOfComponentsMinValue_16();
  public int GetNumberOfComponentsMinValue()
    { return GetNumberOfComponentsMinValue_16(); }

  private native int GetNumberOfComponentsMaxValue_17();
  public int GetNumberOfComponentsMaxValue()
    { return GetNumberOfComponentsMaxValue_17(); }

  private native int GetNumberOfComponents_18();
  public int GetNumberOfComponents()
    { return GetNumberOfComponents_18(); }

  private native void SetMinimumComponentValue_19(double id0);
  public void SetMinimumComponentValue(double id0)
    { SetMinimumComponentValue_19(id0); }

  private native double GetMinimumComponentValue_20();
  public double GetMinimumComponentValue()
    { return GetMinimumComponentValue_20(); }

  private native void SetComponentRange_21(double id0,double id1);
  public void SetComponentRange(double id0,double id1)
    { SetComponentRange_21(id0,id1); }

  private native void SetMaximumComponentValue_22(double id0);
  public void SetMaximumComponentValue(double id0)
    { SetMaximumComponentValue_22(id0); }

  private native double GetMaximumComponentValue_23();
  public double GetMaximumComponentValue()
    { return GetMaximumComponentValue_23(); }

  private native void SetNumberOfTuples_24(int id0);
  public void SetNumberOfTuples(int id0)
    { SetNumberOfTuples_24(id0); }

  private native int GetNumberOfTuplesMinValue_25();
  public int GetNumberOfTuplesMinValue()
    { return GetNumberOfTuplesMinValue_25(); }

  private native int GetNumberOfTuplesMaxValue_26();
  public int GetNumberOfTuplesMaxValue()
    { return GetNumberOfTuplesMaxValue_26(); }

  private native int GetNumberOfTuples_27();
  public int GetNumberOfTuples()
    { return GetNumberOfTuples_27(); }

  private native void SetGeneratePointScalars_28(int id0);
  public void SetGeneratePointScalars(int id0)
    { SetGeneratePointScalars_28(id0); }

  private native int GetGeneratePointScalars_29();
  public int GetGeneratePointScalars()
    { return GetGeneratePointScalars_29(); }

  private native void GeneratePointScalarsOn_30();
  public void GeneratePointScalarsOn()
    { GeneratePointScalarsOn_30(); }

  private native void GeneratePointScalarsOff_31();
  public void GeneratePointScalarsOff()
    { GeneratePointScalarsOff_31(); }

  private native void SetGeneratePointVectors_32(int id0);
  public void SetGeneratePointVectors(int id0)
    { SetGeneratePointVectors_32(id0); }

  private native int GetGeneratePointVectors_33();
  public int GetGeneratePointVectors()
    { return GetGeneratePointVectors_33(); }

  private native void GeneratePointVectorsOn_34();
  public void GeneratePointVectorsOn()
    { GeneratePointVectorsOn_34(); }

  private native void GeneratePointVectorsOff_35();
  public void GeneratePointVectorsOff()
    { GeneratePointVectorsOff_35(); }

  private native void SetGeneratePointNormals_36(int id0);
  public void SetGeneratePointNormals(int id0)
    { SetGeneratePointNormals_36(id0); }

  private native int GetGeneratePointNormals_37();
  public int GetGeneratePointNormals()
    { return GetGeneratePointNormals_37(); }

  private native void GeneratePointNormalsOn_38();
  public void GeneratePointNormalsOn()
    { GeneratePointNormalsOn_38(); }

  private native void GeneratePointNormalsOff_39();
  public void GeneratePointNormalsOff()
    { GeneratePointNormalsOff_39(); }

  private native void SetGeneratePointTensors_40(int id0);
  public void SetGeneratePointTensors(int id0)
    { SetGeneratePointTensors_40(id0); }

  private native int GetGeneratePointTensors_41();
  public int GetGeneratePointTensors()
    { return GetGeneratePointTensors_41(); }

  private native void GeneratePointTensorsOn_42();
  public void GeneratePointTensorsOn()
    { GeneratePointTensorsOn_42(); }

  private native void GeneratePointTensorsOff_43();
  public void GeneratePointTensorsOff()
    { GeneratePointTensorsOff_43(); }

  private native void SetGeneratePointTCoords_44(int id0);
  public void SetGeneratePointTCoords(int id0)
    { SetGeneratePointTCoords_44(id0); }

  private native int GetGeneratePointTCoords_45();
  public int GetGeneratePointTCoords()
    { return GetGeneratePointTCoords_45(); }

  private native void GeneratePointTCoordsOn_46();
  public void GeneratePointTCoordsOn()
    { GeneratePointTCoordsOn_46(); }

  private native void GeneratePointTCoordsOff_47();
  public void GeneratePointTCoordsOff()
    { GeneratePointTCoordsOff_47(); }

  private native void SetGeneratePointArray_48(int id0);
  public void SetGeneratePointArray(int id0)
    { SetGeneratePointArray_48(id0); }

  private native int GetGeneratePointArray_49();
  public int GetGeneratePointArray()
    { return GetGeneratePointArray_49(); }

  private native void GeneratePointArrayOn_50();
  public void GeneratePointArrayOn()
    { GeneratePointArrayOn_50(); }

  private native void GeneratePointArrayOff_51();
  public void GeneratePointArrayOff()
    { GeneratePointArrayOff_51(); }

  private native void SetGenerateCellScalars_52(int id0);
  public void SetGenerateCellScalars(int id0)
    { SetGenerateCellScalars_52(id0); }

  private native int GetGenerateCellScalars_53();
  public int GetGenerateCellScalars()
    { return GetGenerateCellScalars_53(); }

  private native void GenerateCellScalarsOn_54();
  public void GenerateCellScalarsOn()
    { GenerateCellScalarsOn_54(); }

  private native void GenerateCellScalarsOff_55();
  public void GenerateCellScalarsOff()
    { GenerateCellScalarsOff_55(); }

  private native void SetGenerateCellVectors_56(int id0);
  public void SetGenerateCellVectors(int id0)
    { SetGenerateCellVectors_56(id0); }

  private native int GetGenerateCellVectors_57();
  public int GetGenerateCellVectors()
    { return GetGenerateCellVectors_57(); }

  private native void GenerateCellVectorsOn_58();
  public void GenerateCellVectorsOn()
    { GenerateCellVectorsOn_58(); }

  private native void GenerateCellVectorsOff_59();
  public void GenerateCellVectorsOff()
    { GenerateCellVectorsOff_59(); }

  private native void SetGenerateCellNormals_60(int id0);
  public void SetGenerateCellNormals(int id0)
    { SetGenerateCellNormals_60(id0); }

  private native int GetGenerateCellNormals_61();
  public int GetGenerateCellNormals()
    { return GetGenerateCellNormals_61(); }

  private native void GenerateCellNormalsOn_62();
  public void GenerateCellNormalsOn()
    { GenerateCellNormalsOn_62(); }

  private native void GenerateCellNormalsOff_63();
  public void GenerateCellNormalsOff()
    { GenerateCellNormalsOff_63(); }

  private native void SetGenerateCellTensors_64(int id0);
  public void SetGenerateCellTensors(int id0)
    { SetGenerateCellTensors_64(id0); }

  private native int GetGenerateCellTensors_65();
  public int GetGenerateCellTensors()
    { return GetGenerateCellTensors_65(); }

  private native void GenerateCellTensorsOn_66();
  public void GenerateCellTensorsOn()
    { GenerateCellTensorsOn_66(); }

  private native void GenerateCellTensorsOff_67();
  public void GenerateCellTensorsOff()
    { GenerateCellTensorsOff_67(); }

  private native void SetGenerateCellTCoords_68(int id0);
  public void SetGenerateCellTCoords(int id0)
    { SetGenerateCellTCoords_68(id0); }

  private native int GetGenerateCellTCoords_69();
  public int GetGenerateCellTCoords()
    { return GetGenerateCellTCoords_69(); }

  private native void GenerateCellTCoordsOn_70();
  public void GenerateCellTCoordsOn()
    { GenerateCellTCoordsOn_70(); }

  private native void GenerateCellTCoordsOff_71();
  public void GenerateCellTCoordsOff()
    { GenerateCellTCoordsOff_71(); }

  private native void SetGenerateCellArray_72(int id0);
  public void SetGenerateCellArray(int id0)
    { SetGenerateCellArray_72(id0); }

  private native int GetGenerateCellArray_73();
  public int GetGenerateCellArray()
    { return GetGenerateCellArray_73(); }

  private native void GenerateCellArrayOn_74();
  public void GenerateCellArrayOn()
    { GenerateCellArrayOn_74(); }

  private native void GenerateCellArrayOff_75();
  public void GenerateCellArrayOff()
    { GenerateCellArrayOff_75(); }

  private native void SetGenerateFieldArray_76(int id0);
  public void SetGenerateFieldArray(int id0)
    { SetGenerateFieldArray_76(id0); }

  private native int GetGenerateFieldArray_77();
  public int GetGenerateFieldArray()
    { return GetGenerateFieldArray_77(); }

  private native void GenerateFieldArrayOn_78();
  public void GenerateFieldArrayOn()
    { GenerateFieldArrayOn_78(); }

  private native void GenerateFieldArrayOff_79();
  public void GenerateFieldArrayOff()
    { GenerateFieldArrayOff_79(); }

  private native void SetAttributesConstantPerBlock_80(boolean id0);
  public void SetAttributesConstantPerBlock(boolean id0)
    { SetAttributesConstantPerBlock_80(id0); }

  private native boolean GetAttributesConstantPerBlock_81();
  public boolean GetAttributesConstantPerBlock()
    { return GetAttributesConstantPerBlock_81(); }

  private native void AttributesConstantPerBlockOn_82();
  public void AttributesConstantPerBlockOn()
    { AttributesConstantPerBlockOn_82(); }

  private native void AttributesConstantPerBlockOff_83();
  public void AttributesConstantPerBlockOff()
    { AttributesConstantPerBlockOff_83(); }

  private native void GenerateAllPointDataOn_84();
  public void GenerateAllPointDataOn()
    { GenerateAllPointDataOn_84(); }

  private native void GenerateAllPointDataOff_85();
  public void GenerateAllPointDataOff()
    { GenerateAllPointDataOff_85(); }

  private native void GenerateAllCellDataOn_86();
  public void GenerateAllCellDataOn()
    { GenerateAllCellDataOn_86(); }

  private native void GenerateAllCellDataOff_87();
  public void GenerateAllCellDataOff()
    { GenerateAllCellDataOff_87(); }

  private native void GenerateAllDataOn_88();
  public void GenerateAllDataOn()
    { GenerateAllDataOn_88(); }

  private native void GenerateAllDataOff_89();
  public void GenerateAllDataOff()
    { GenerateAllDataOff_89(); }

  public vtkRandomAttributeGenerator() { super(); }

  public vtkRandomAttributeGenerator(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.2-1-aarch64.pkg.tar.xz: vtk/vtkRandomAttributeGenerator.java <==
// java wrapper for vtkRandomAttributeGenerator object
//

package vtk;
import vtk.*;

public class vtkRandomAttributeGenerator extends vtkPassInputTypeAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetDataType_2(int id0);
  public void SetDataType(int id0)
    { SetDataType_2(id0); }

  private native void SetDataTypeToBit_3();
  public void SetDataTypeToBit()
    { SetDataTypeToBit_3(); }

  private native void SetDataTypeToChar_4();
  public void SetDataTypeToChar()
    { SetDataTypeToChar_4(); }

  private native void SetDataTypeToUnsignedChar_5();
  public void SetDataTypeToUnsignedChar()
    { SetDataTypeToUnsignedChar_5(); }

  private native void SetDataTypeToShort_6();
  public void SetDataTypeToShort()
    { SetDataTypeToShort_6(); }

  private native void SetDataTypeToUnsignedShort_7();
  public void SetDataTypeToUnsignedShort()
    { SetDataTypeToUnsignedShort_7(); }

  private native void SetDataTypeToInt_8();
  public void SetDataTypeToInt()
    { SetDataTypeToInt_8(); }

  private native void SetDataTypeToUnsignedInt_9();
  public void SetDataTypeToUnsignedInt()
    { SetDataTypeToUnsignedInt_9(); }

  private native void SetDataTypeToLong_10();
  public void SetDataTypeToLong()
    { SetDataTypeToLong_10(); }

  private native void SetDataTypeToUnsignedLong_11();
  public void SetDataTypeToUnsignedLong()
    { SetDataTypeToUnsignedLong_11(); }

  private native void SetDataTypeToFloat_12();
  public void SetDataTypeToFloat()
    { SetDataTypeToFloat_12(); }

  private native void SetDataTypeToDouble_13();
  public void SetDataTypeToDouble()
    { SetDataTypeToDouble_13(); }

  private native int GetDataType_14();
  public int GetDataType()
    { return GetDataType_14(); }

  private native void SetNumberOfComponents_15(int id0);
  public void SetNumberOfComponents(int id0)
    { SetNumberOfComponents_15(id0); }

  private native int GetNumberOfComponentsMinValue_16();
  public int GetNumberOfComponentsMinValue()
    { return GetNumberOfComponentsMinValue_16(); }

  private native int GetNumberOfComponentsMaxValue_17();
  public int GetNumberOfComponentsMaxValue()
    { return GetNumberOfComponentsMaxValue_17(); }

  private native int GetNumberOfComponents_18();
  public int GetNumberOfComponents()
    { return GetNumberOfComponents_18(); }

  private native void SetMinimumComponentValue_19(double id0);
  public void SetMinimumComponentValue(double id0)
    { SetMinimumComponentValue_19(id0); }

  private native double GetMinimumComponentValue_20();
  public double GetMinimumComponentValue()
    { return GetMinimumComponentValue_20(); }

  private native void SetComponentRange_21(double id0,double id1);
  public void SetComponentRange(double id0,double id1)
    { SetComponentRange_21(id0,id1); }

  private native void SetMaximumComponentValue_22(double id0);
  public void SetMaximumComponentValue(double id0)
    { SetMaximumComponentValue_22(id0); }

  private native double GetMaximumComponentValue_23();
  public double GetMaximumComponentValue()
    { return GetMaximumComponentValue_23(); }

  private native void SetNumberOfTuples_24(int id0);
  public void SetNumberOfTuples(int id0)
    { SetNumberOfTuples_24(id0); }

  private native int GetNumberOfTuplesMinValue_25();
  public int GetNumberOfTuplesMinValue()
    { return GetNumberOfTuplesMinValue_25(); }

  private native int GetNumberOfTuplesMaxValue_26();
  public int GetNumberOfTuplesMaxValue()
    { return GetNumberOfTuplesMaxValue_26(); }

  private native int GetNumberOfTuples_27();
  public int GetNumberOfTuples()
    { return GetNumberOfTuples_27(); }

  private native void SetGeneratePointScalars_28(int id0);
  public void SetGeneratePointScalars(int id0)
    { SetGeneratePointScalars_28(id0); }

  private native int GetGeneratePointScalars_29();
  public int GetGeneratePointScalars()
    { return GetGeneratePointScalars_29(); }

  private native void GeneratePointScalarsOn_30();
  public void GeneratePointScalarsOn()
    { GeneratePointScalarsOn_30(); }

  private native void GeneratePointScalarsOff_31();
  public void GeneratePointScalarsOff()
    { GeneratePointScalarsOff_31(); }

  private native void SetGeneratePointVectors_32(int id0);
  public void SetGeneratePointVectors(int id0)
    { SetGeneratePointVectors_32(id0); }

  private native int GetGeneratePointVectors_33();
  public int GetGeneratePointVectors()
    { return GetGeneratePointVectors_33(); }

  private native void GeneratePointVectorsOn_34();
  public void GeneratePointVectorsOn()
    { GeneratePointVectorsOn_34(); }

  private native void GeneratePointVectorsOff_35();
  public void GeneratePointVectorsOff()
    { GeneratePointVectorsOff_35(); }

  private native void SetGeneratePointNormals_36(int id0);
  public void SetGeneratePointNormals(int id0)
    { SetGeneratePointNormals_36(id0); }

  private native int GetGeneratePointNormals_37();
  public int GetGeneratePointNormals()
    { return GetGeneratePointNormals_37(); }

  private native void GeneratePointNormalsOn_38();
  public void GeneratePointNormalsOn()
    { GeneratePointNormalsOn_38(); }

  private native void GeneratePointNormalsOff_39();
  public void GeneratePointNormalsOff()
    { GeneratePointNormalsOff_39(); }

  private native void SetGeneratePointTensors_40(int id0);
  public void SetGeneratePointTensors(int id0)
    { SetGeneratePointTensors_40(id0); }

  private native int GetGeneratePointTensors_41();
  public int GetGeneratePointTensors()
    { return GetGeneratePointTensors_41(); }

  private native void GeneratePointTensorsOn_42();
  public void GeneratePointTensorsOn()
    { GeneratePointTensorsOn_42(); }

  private native void GeneratePointTensorsOff_43();
  public void GeneratePointTensorsOff()
    { GeneratePointTensorsOff_43(); }

  private native void SetGeneratePointTCoords_44(int id0);
  public void SetGeneratePointTCoords(int id0)
    { SetGeneratePointTCoords_44(id0); }

  private native int GetGeneratePointTCoords_45();
  public int GetGeneratePointTCoords()
    { return GetGeneratePointTCoords_45(); }

  private native void GeneratePointTCoordsOn_46();
  public void GeneratePointTCoordsOn()
    { GeneratePointTCoordsOn_46(); }

  private native void GeneratePointTCoordsOff_47();
  public void GeneratePointTCoordsOff()
    { GeneratePointTCoordsOff_47(); }

  private native void SetGeneratePointArray_48(int id0);
  public void SetGeneratePointArray(int id0)
    { SetGeneratePointArray_48(id0); }

  private native int GetGeneratePointArray_49();
  public int GetGeneratePointArray()
    { return GetGeneratePointArray_49(); }

  private native void GeneratePointArrayOn_50();
  public void GeneratePointArrayOn()
    { GeneratePointArrayOn_50(); }

  private native void GeneratePointArrayOff_51();
  public void GeneratePointArrayOff()
    { GeneratePointArrayOff_51(); }

  private native void SetGenerateCellScalars_52(int id0);
  public void SetGenerateCellScalars(int id0)
    { SetGenerateCellScalars_52(id0); }

  private native int GetGenerateCellScalars_53();
  public int GetGenerateCellScalars()
    { return GetGenerateCellScalars_53(); }

  private native void GenerateCellScalarsOn_54();
  public void GenerateCellScalarsOn()
    { GenerateCellScalarsOn_54(); }

  private native void GenerateCellScalarsOff_55();
  public void GenerateCellScalarsOff()
    { GenerateCellScalarsOff_55(); }

  private native void SetGenerateCellVectors_56(int id0);
  public void SetGenerateCellVectors(int id0)
    { SetGenerateCellVectors_56(id0); }

  private native int GetGenerateCellVectors_57();
  public int GetGenerateCellVectors()
    { return GetGenerateCellVectors_57(); }

  private native void GenerateCellVectorsOn_58();
  public void GenerateCellVectorsOn()
    { GenerateCellVectorsOn_58(); }

  private native void GenerateCellVectorsOff_59();
  public void GenerateCellVectorsOff()
    { GenerateCellVectorsOff_59(); }

  private native void SetGenerateCellNormals_60(int id0);
  public void SetGenerateCellNormals(int id0)
    { SetGenerateCellNormals_60(id0); }

  private native int GetGenerateCellNormals_61();
  public int GetGenerateCellNormals()
    { return GetGenerateCellNormals_61(); }

  private native void GenerateCellNormalsOn_62();
  public void GenerateCellNormalsOn()
    { GenerateCellNormalsOn_62(); }

  private native void GenerateCellNormalsOff_63();
  public void GenerateCellNormalsOff()
    { GenerateCellNormalsOff_63(); }

  private native void SetGenerateCellTensors_64(int id0);
  public void SetGenerateCellTensors(int id0)
    { SetGenerateCellTensors_64(id0); }

  private native int GetGenerateCellTensors_65();
  public int GetGenerateCellTensors()
    { return GetGenerateCellTensors_65(); }

  private native void GenerateCellTensorsOn_66();
  public void GenerateCellTensorsOn()
    { GenerateCellTensorsOn_66(); }

  private native void GenerateCellTensorsOff_67();
  public void GenerateCellTensorsOff()
    { GenerateCellTensorsOff_67(); }

  private native void SetGenerateCellTCoords_68(int id0);
  public void SetGenerateCellTCoords(int id0)
    { SetGenerateCellTCoords_68(id0); }

  private native int GetGenerateCellTCoords_69();
  public int GetGenerateCellTCoords()
    { return GetGenerateCellTCoords_69(); }

  private native void GenerateCellTCoordsOn_70();
  public void GenerateCellTCoordsOn()
    { GenerateCellTCoordsOn_70(); }

  private native void GenerateCellTCoordsOff_71();
  public void GenerateCellTCoordsOff()
    { GenerateCellTCoordsOff_71(); }

  private native void SetGenerateCellArray_72(int id0);
  public void SetGenerateCellArray(int id0)
    { SetGenerateCellArray_72(id0); }

  private native int GetGenerateCellArray_73();
  public int GetGenerateCellArray()
    { return GetGenerateCellArray_73(); }

  private native void GenerateCellArrayOn_74();
  public void GenerateCellArrayOn()
    { GenerateCellArrayOn_74(); }

  private native void GenerateCellArrayOff_75();
  public void GenerateCellArrayOff()
    { GenerateCellArrayOff_75(); }

  private native void SetGenerateFieldArray_76(int id0);
  public void SetGenerateFieldArray(int id0)
    { SetGenerateFieldArray_76(id0); }

  private native int GetGenerateFieldArray_77();
  public int GetGenerateFieldArray()
    { return GetGenerateFieldArray_77(); }

  private native void GenerateFieldArrayOn_78();
  public void GenerateFieldArrayOn()
    { GenerateFieldArrayOn_78(); }

  private native void GenerateFieldArrayOff_79();
  public void GenerateFieldArrayOff()
    { GenerateFieldArrayOff_79(); }

  private native void SetAttributesConstantPerBlock_80(boolean id0);
  public void SetAttributesConstantPerBlock(boolean id0)
    { SetAttributesConstantPerBlock_80(id0); }

  private native boolean GetAttributesConstantPerBlock_81();
  public boolean GetAttributesConstantPerBlock()
    { return GetAttributesConstantPerBlock_81(); }

  private native void AttributesConstantPerBlockOn_82();
  public void AttributesConstantPerBlockOn()
    { AttributesConstantPerBlockOn_82(); }

  private native void AttributesConstantPerBlockOff_83();
  public void AttributesConstantPerBlockOff()
    { AttributesConstantPerBlockOff_83(); }

  private native void GenerateAllPointDataOn_84();
  public void GenerateAllPointDataOn()
    { GenerateAllPointDataOn_84(); }

  private native void GenerateAllPointDataOff_85();
  public void GenerateAllPointDataOff()
    { GenerateAllPointDataOff_85(); }

  private native void GenerateAllCellDataOn_86();
  public void GenerateAllCellDataOn()
    { GenerateAllCellDataOn_86(); }

  private native void GenerateAllCellDataOff_87();
  public void GenerateAllCellDataOff()
    { GenerateAllCellDataOff_87(); }

  private native void GenerateAllDataOn_88();
  public void GenerateAllDataOn()
    { GenerateAllDataOn_88(); }

  private native void GenerateAllDataOff_89();
  public void GenerateAllDataOff()
    { GenerateAllDataOff_89(); }

  public vtkRandomAttributeGenerator() { super(); }

  public vtkRandomAttributeGenerator(long id) { super(id); }
  public native long   VTKInit();

}
